Commit 1922e498e34f17ee743d7c57449b0decaf162842

Con Kolivas 2012-12-10T11:03:50

Only stratum pools that are idle need to be kicked via cnx_needed.

1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
diff --git a/cgminer.c b/cgminer.c
index deb541c..58aeb2d 100644
--- a/cgminer.c
+++ b/cgminer.c
@@ -4507,8 +4507,8 @@ static bool cnx_needed(struct pool *pool)
 	if (pool_strategy == POOL_LOADBALANCE)
 		return true;
 
-	/* Idle pool needs something to kick it alive again */
-	if (pool->idle)
+	/* Idle stratum pool needs something to kick it alive again */
+	if (pool->has_stratum && pool->idle)
 		return true;
 
 	/* Getwork pools without opt_fail_only need backup pools up to be able